

// SPGSimpleGeneticAlg.cpp
// Copyright 2006 Steve Gargolinski

/*
This file is part of SPGGenomePool.

SPGGenomePool is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

SPGGenomePool is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with SPGGenomePool; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


#include <tchar.h>
#include <time.h>
#include "SPGGenome.h"
#include "SPGGenomePool.h"



// Here is a very trivial example of how to use this genetic algorithm class

class SPGGenomePoolRandom : public SPGGenomePool
{

public:

	// We need to make sure to override CalcGenomeStrengths()
	virtual void CalcGenomeStrengths();
};


void SPGGenomePoolRandom::CalcGenomeStrengths()
{
	// Loop through all of the genomes and figure out their strengths
	for (size_t i = 0; i < m_genomeList.size(); ++i)
	{
		SPGGenome* genome = m_genomeList[i];
		if (genome != NULL)
		{
			// Just as an example, set the strength to a random number
			genome->SetStrength((rand() / (RAND_MAX + 1.0f)));
		}
	}
}



int _tmain(int argc, _TCHAR* argv[])
{
	// Make sure we seed the random numbers
	srand((unsigned int)time(NULL));

	// Setup a pool
	SPGGenomePoolRandom pool;

	// Create our initial pool
	pool.CreateInitialPool();

	// And keep running generations until pool.GetCurrentStrongestGenome() returns a genome
	// that has a strength value high enough to be a good solution
	pool.RunGeneration();



	return 0;
}

